@@ -15,9 +15,10 @@ import tempfile
 import traceback
 
 import click
+import sqliteparser
 from tabulate import tabulate
 
-from .core import CreateTableMigration, Database, DropTableMigration
+from . import Database, migrations
 
 # Help strings used in multiple places.
 HELP_COLUMNS = "Only display these columns in the results."
@@ -107,8 +108,7 @@ def main_create_wrapper(*args, **kwargs):
 
 def main_create(db_path, table, payload, *, auto_timestamp=True):
     if not payload:
-        print("Error: Payload must not be empty.", file=sys.stderr)
-        sys.exit(1)
+        report_error_and_exit("payload must not be empty")
 
     payload_as_map = {}
     for key_value in payload:
@@ -446,39 +446,56 @@ def base_list(
             prettyprint_rows(rows, columns=columns, hide=hide, page=page)
 
 
-@cli.command(name="list-tables")
+@cli.command(name="schema")
 @click.argument("db_path")
-def main_list_tables_wrapper(*args, **kwargs):
+@click.argument("table", required=False, default=None)
+@click.option("--as-python", is_flag=True, default=False)
+def main_schema_wrapper(*args, **kwargs):
     """
     List the names of the tables in the database.
     """
-    main_list_tables(*args, **kwargs)
+    main_schema(*args, **kwargs)
 
 
-def main_list_tables(db_path):
+def main_schema(db_path, table=None, *, as_python=False):
     with Database(db_path, readonly=True) as db:
-        rows = db.sql(
-            """
-            SELECT
-              name
-            FROM
-              sqlite_master
-            WHERE
-              type = 'table'
-            AND
-              name NOT LIKE 'sqlite_%'
-            """,
-            as_tuple=True,
-        )
+        if table is not None:
+            row = db.get(
+                "sqlite_master",
+                where="type = 'table' AND name = :table",
+                values={"table": table},
+            )
+            sql = row["sql"]
 
-        if rows:
-            print("\n".join(row[0] for row in rows))
+            if as_python:
+                raise NotImplementedError
+            else:
+                try:
+                    # Use sqliteparser to parse and pretty-print the table schema.
+                    create_table_statement = sqliteparser.parse(sql)[0]
+                    print(create_table_statement)
+                except sqliteparser.SQLiteParserError:
+                    # If sqliteparser can't parse the table schema, just directly print
+                    # what SQLite returned to us.
+                    print(sql)
+        else:
+            if as_python:
+                raise NotImplementedError
+            else:
+                rows = db.list(
+                    "sqlite_master",
+                    where="type = 'table' AND name NOT LIKE 'sqlite_%'",
+                    order_by="name",
+                )
+
+            if rows:
+                print("\n".join(row["name"] for row in rows))
 
 
 @cli.command(name="migrate")
 @click.argument("db_path")
 @click.argument("schema_path")
-@click.argument("table", required=False, default=None)
+@click.option("--table", default=None)
 @click.option(
     "--write",
     is_flag=True,
@@ -514,7 +531,7 @@ def main_migrate(db_path, schema_path, table, *, write, no_backup, debug):
     ) as db:
         diff = db.diff(schema, table=table)
         if not diff:
-            print("Nothing to migrate - database matches schema.")
+            print("Nothing to migrate: database matches schema.")
             return
 
         if write and not no_backup:
@@ -532,11 +549,15 @@ def main_migrate(db_path, schema_path, table, *, write, no_backup, debug):
             else:
                 printed = True
 
-            if len(table_diff) == 1 and isinstance(table_diff[0], CreateTableMigration):
+            if len(table_diff) == 1 and isinstance(
+                table_diff[0], migrations.CreateTableMigration
+            ):
                 op = table_diff[0]
                 print(f"Create table {op.table_name}")
                 tables_created += 1
-            elif len(table_diff) == 1 and isinstance(table_diff[0], DropTableMigration):
+            elif len(table_diff) == 1 and isinstance(
+                table_diff[0], migrations.DropTableMigration
+            ):
                 op = table_diff[0]
                 print(f"Drop table {op.table_name}")
                 tables_dropped += 1
@@ -749,8 +770,7 @@ def main_update_wrapper(*args, **kwargs):
 
 def main_update(db_path, table, pk, payload, *, auto_timestamp=True):
     if not payload:
-        print("Error: Payload must not be empty.", file=sys.stderr)
-        sys.exit(1)
+        report_error_and_exit("payload must not be empty")
 
     payload_as_map = {}
     for key_value in payload:
@@ -855,6 +875,14 @@ def get_schema_from_path(schema_path):
         return None
 
     spec = importlib.util.spec_from_file_location("schema", schema_path)
+    if spec is None:
+        report_error_and_exit(f"could not load schema file at {schema_path}")
+
     schema_module = importlib.util.module_from_spec(spec)
     spec.loader.exec_module(schema_module)
     return schema_module.SCHEMA
+
+
+def report_error_and_exit(message):
+    print(f"Error: {message}", file=sys.stderr)
+    sys.exit(1)
